@@ -253,9 +253,10 @@ def gen_class_h(bdir, data):
 	for c in data.CLASS_LIST:
 		if not c.struct_name.endswith("_t"):
 			op = ''
-			if c.cname == 'Method':   op = '\tknh_fmethod fcall_1;\n\tvoid *pc_start;\n'
+			if c.cname == 'Method':   op = '\tknh_fmethod fcall_1;\n\tknh_code_t *pc_start;\n'
 			if c.cname == 'Mapper':   op = '\tknh_fmapper fmap_1;\n'
 			if c.cname == 'Iterator': op = '\tknh_fitrnext fnext_1;\n'
+			if c.cname == 'Closure': op = '\tknh_fmethod finvoke_1;\n\tknh_fmethod fcallcc_2;\n'
 			if c.cname == 'Token':    op = '\tknh_fileid_t fileid;\n\tknh_ushort_t line;\n\tknh_flag_t flag;\n\tknh_token_t  tt;\n'
 			if c.cname == 'Stmt':     op = '\tknh_fileid_t fileid;\n\tknh_ushort_t line;\n\tknh_flag_t flag;\n\tknh_stmt_t  stt;\n'
 			#if c.cname == 'Asm': op = '\tknh_fileid_t fileid;\n\tknh_ushort_t line;\n\tknh_flag_t flag;\n\tknh_ushort_t dummy;\n'
