@@ -182,9 +182,9 @@ def gen_name_h(bdir, data):
 		for c in p.CLASS_LIST:
 			if c.hasStruct():
 				op = ''
-				if c.cname == 'Method':   op = '\tknh_fmethod fcall_1;\n\tvoid *code_2;\n'
+				if c.cname == 'Method':   op = '\tknh_fmethod fcall_1;\n\tknh_code_t *pc_start;\n'
 				if c.cname == 'Mapper':   op = '\tknh_fmapper fmap_1;\n'
-				if c.cname == 'Iterator': op = '\tf_next fnext_1;\n'
+				if c.cname == 'Iterator': op = '\tknh_fitrnext fnext_1;\n'
 				#if c.cname == 'Token':    op = '\tknh_fileid_t fileid;\n\tknh_ushort_t line;\n\tknh_flag_t flag;\n\tknh_token_t  tt;\n'
 				#if c.cname == 'Stmt':     op = '\tknh_fileid_t fileid;\n\tknh_ushort_t line;\n\tknh_flag_t flag;\n\tknh_stmt_t  stt;\n'
 				#if c.cname == 'Asm': op = '\tknh_fileid_t fileid;\n\tknh_ushort_t line;\n\tknh_flag_t flag;\n\tknh_ushort_t dummy;\n'
@@ -276,62 +276,8 @@ METHOD %s_%s(Ctx *ctx, knh_sfp_t *sfp)
 ''' % (methodbase, ffn, funcbase, ffn, a1))
 
 def write_ctable_c(f, c, data):
-	if c.isTuple() : return
-	if not c.hasStruct():
-		f.write('''
-static INLINE
-knh_struct_t
-KNH_TSTRUCT_$1(Ctx *ctx,
-	knh_struct_t sid,
-	size_t size,
-	char *name,
-	void *finit, void *fcopy, void *fgc,
-	knh_hcode_t (*fhashCode)($1*),
-	int (*fcompareTo)($1*, $1*)) {
-	return KNH_TSTRUCT(ctx, sid, size, name, finit, fcopy, fgc,
-		(f_hashCode)fhashCode, (f_compareTo)fcompareTo);
-}
-'''.replace('$1', c.cname))
-		return
-	
-	f.write('''
-static INLINE
-knh_struct_t
-KNH_TSTRUCT_$1(Ctx *ctx,
-	knh_struct_t sid,
-	size_t size,
-	char *name,
-	void (*finit)(Ctx*, knh_$1*, int, Object*),
-	void (*fcopy)(Ctx*, knh_$1*, knh_$1*),
-	void (*fgc)(Ctx*, knh_$1*, knh_ftraverse),
-	knh_hcode_t (*fhashCode)($1*),
-	int (*fcompareTo)($1*, $1*)) {
-	return KNH_TSTRUCT(ctx, sid, size, name, 
-		(f_tStruct_init)finit, (f_tStruct_copy)fcopy, (f_tStruct_traverse)fgc,
-		(f_hashCode)fhashCode, (f_compareTo)fcompareTo);
-}
-'''.replace('$1', c.cname))
+	return
 
-def write_struct_c(f, c, data):
-	if c.isTuple() : return
-	fh = '%s_hashCode' % (c.funcbase)
-	if not data.FUNC_MAP.has_key(fh) : fh = 'NULL'
-	fc = '%s_compareTo' % (c.funcbase)
-	if not data.FUNC_MAP.has_key(fc) : fc = 'NULL'
-	
-	if not c.hasStruct():
-		f.write('''
-\tKNH_TSTRUCT_%s(ctx, %s, 0, "%s", NULL, NULL, NULL, %s, %s); ''' % (c.cname, STRUCT_cname(c.cname), c.cname, fh, fc))
-		return
-	f.write('''
-\tKNH_TSTRUCT_%s(ctx, %s, sizeof(%s),
-\t\t"%s",
-\t\t%s_struct_init,
-\t\t%s_struct_copy, 
-//\t\t%s_struct_compare, 
-\t\t%s_struct_traverse,
-\t\t%s,
-\t\t%s);''' % (c.cname, STRUCT_cname(c.cname), c.struct_name, c.cname, c.funcbase, c.funcbase, c.funcbase, c.funcbase, fh, fc))
 
 def write_class_c(f, c, data):
 	f.write('''
@@ -449,14 +395,14 @@ METHOD %s(Ctx *ctx, knh_sfp_t *sfp)
 	ki = 0
 	for p in params[ci:]:
 		n = 'sfp[%d].o' % (ki + 1)
-		if p.type == 'knh_vargc_t':
+		if p.type == 'int':
 			f.write(''',
 \t\tknh_sfp_argc(ctx, sfp + %d),
 \t\tsfp + %d''' % ((ki + 1), (ki + 1)))
 			break
 		if p.type == 'knh_hcode_t':
 			f.write(''',
-\t\tknh_Object_hashCode(%s)''' % n)
+\t\tknh_Object_hashCode(Ctx *ctx, %s)''' % n)
 			continue
 		if ki < len(mtd.params):
 			f.write(''',
@@ -492,10 +438,8 @@ def gen_class_c(bdir, p, data):
 void knh_%s_initapis(Ctx *ctx)
 {
 ''' % p.pname)
-#	for c in p.CLASS_LIST:
-#		write_struct_c(f, c, data)
-#	for c in p.CLASS_LIST:
-#		write_class_c(f, c, data)
+	for c in p.CLASS_LIST:
+		write_class_c(f, c, data)
 	for mtd in p.METHOD_LIST:
 		write_method_c(f, mtd, data)
 	for mm in p.MAPMAP_LIST:
@@ -572,8 +516,8 @@ void konoha_class_init0(Ctx *ctx)
 	for p in data.PACKAGE_LIST:
 		p = data.package(p)
 		write_section(f, p.package)
-		for c in p.CLASS_LIST:
-			write_struct_c(f, c, data)
+#		for c in p.CLASS_LIST:
+#			write_struct_c(f, c, data)
 		for c in p.CLASS_LIST:
 			write_class_c(f, c, data)
 	
