@@ -47,8 +47,9 @@ ISNNTYPE sfi type
 
 FCALL sfi ushort sfi mtd
 SCALL sfi ushort mtd 
+AINVOKE sfi ushort mtd
 CALL  sfi ushort mn 
-ACALL sfi ushort mn type
+ACALL sfi ushort mn
 NEW   sfi flag cid ushort mtd
 
 TOSTR      sfi mn
