@@ -293,7 +293,6 @@ METHOD knh__System_getOut(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__System_setOut(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__System_getErr(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__System_setErr(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__System_gc(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__System_exit(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__System_hasDir(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__System_hasFile(Ctx *ctx, knh_sfp_t *sfp);
@@ -518,7 +517,7 @@ Method* new_Method(Ctx *ctx, knh_flag_t flag, knh_class_t cid, knh_methodn_t mn,
 knh_bool_t knh_Method_isNoSuchMethod(Method *o);
 Method* new_Method__NoSuchMethod(Ctx *ctx, knh_class_t cid, knh_methodn_t mn);
 int knh_methodn_isNew(Ctx *ctx, knh_methodn_t mn);
-int knh_Method_isNew(Ctx *ctx, Method *o);
+int knh_Method_isConstructor(Ctx *ctx, Method *o);
 int knh_methodn_isOp(Ctx *ctx, knh_methodn_t mn);
 String* knh_Method_getName(Ctx *ctx, Method *o);
 String* knh_Method_getURN(Ctx *ctx, Method *o);
@@ -859,9 +858,7 @@ void knh_Object_traverse(Ctx *ctx, knh_Object_t *o, knh_ftraverse ftr);
 void knh_fgchook_nop(Ctx *ctx);
 void knh_fgchook_collect(Ctx *ctx);
 void knh_Object_mark0(Ctx *ctx, Object *o);
-void knh_Object_sweep0(Ctx *ctx, Object *o);
-void knh_Object_mark1(Ctx *ctx, Object *o);
-void knh_Object_sweep1(Ctx *ctx, Object *o);
+METHOD knh__System_gc(Ctx *ctx, knh_sfp_t *sfp);
 void knh_Object_RCsweep(Ctx *ctx, Object *o);
 knh_ftraverse konoha_getDefaultSweepFunction();
 /* ../src/main/konoha_pkgapi.c */
@@ -871,7 +868,7 @@ void knh_stack_p(Ctx *ctx, knh_sfp_t *sfp, knh_flag_t flag, knh_methodn_t mn, in
 int knh_verbose(void);
 /* ../src/main/konoha_stack.c */
 int knh_sfp_argc(Ctx *ctx, knh_sfp_t *varg);
-char * knh_format_mtdparam(Ctx *ctx, char *buf, size_t bufsiz, Method *mtd, int n); void knh_sfp_typecheck(Ctx *ctx, knh_sfp_t *sfp, knh_type_t reqt, Method *mtd, knh_code_t *pc);
+char * knh_format_mtdparam(Ctx *ctx, char *buf, size_t bufsiz, Method *mtd, int n); void knh_sfp_typecheck(Ctx *ctx, knh_sfp_t *sfp, Method *mtd, knh_code_t *pc);
 void knh_sfp_dump(Ctx *ctx, knh_sfp_t *sfp);
 /* ../src/main/konoha_system.c */
 int knh_bytes_isOptionalMT(knh_bytes_t t);
@@ -888,6 +885,7 @@ String *knh_tfileid_name(Ctx *ctx, knh_fileid_t fileid);
 /* ../src/main/konoha_table.c */
 void konoha_initContext(Ctx *ctx, knh_Context_t *o, size_t stacksize);
 void knh_Context_traverse(Ctx *ctx, knh_Context_t *o, knh_ftraverse ftr);
+void konoha_traverse(Ctx* ctx, knh_ftraverse ftr);
 /* ../src/main/konoha_typesystem.c */
 knh_bool_t knh_class_instanceof(Ctx *ctx, knh_class_t scid, knh_class_t tcid);
 METHOD knh__Object_opInstanceof(Ctx *ctx, knh_sfp_t *sfp);
