@@ -49,144 +49,146 @@ extern "C" {
 #define TT_EXTENDS                      ((knh_token_t)6)
 #define TT_IMPLEMENTS                   ((knh_token_t)7)
 #define TT_METHOD                       ((knh_token_t)8)
-#define TT_FORMAT                       ((knh_token_t)9)
-#define TT_RETURN                       ((knh_token_t)10)
-#define TT_MAPMAP                       ((knh_token_t)11)
-#define TT_WEAVE                        ((knh_token_t)12)
-#define TT_ASPECT                       ((knh_token_t)13)
-#define TT_BLOCK                        ((knh_token_t)14)
-#define TT_IF                           ((knh_token_t)15)
-#define TT_ELSE                         ((knh_token_t)16)
-#define TT_SWITCH                       ((knh_token_t)17)
-#define TT_CASE                         ((knh_token_t)18)
-#define TT_WHILE                        ((knh_token_t)19)
-#define TT_DO                           ((knh_token_t)20)
-#define TT_FOR                          ((knh_token_t)21)
-#define TT_FOREACH                      ((knh_token_t)22)
-#define TT_FROM                         ((knh_token_t)23)
-#define TT_WHERE                        ((knh_token_t)24)
-#define TT_BREAK                        ((knh_token_t)25)
-#define TT_CONTINUE                     ((knh_token_t)26)
-#define TT_TRY                          ((knh_token_t)27)
-#define TT_CATCH                        ((knh_token_t)28)
-#define TT_FINALLY                      ((knh_token_t)29)
-#define TT_THROW                        ((knh_token_t)30)
-#define TT_LOCAL                        ((knh_token_t)31)
-#define TT_PRINT                        ((knh_token_t)32)
-#define TT_ASSERT                       ((knh_token_t)33)
-#define TT_BRACE                        ((knh_token_t)34)
-#define TT_PARENTHESIS                  ((knh_token_t)35)
-#define TT_BRANCET                      ((knh_token_t)36)
-#define TT_DOTS                         ((knh_token_t)37)
-#define TT_SEMICOLON                    ((knh_token_t)38)
-#define TT_COMMA                        ((knh_token_t)39)
-#define TT_LET                          ((knh_token_t)40)
-#define TT_LSHIFTE                      ((knh_token_t)41)
-#define TT_RSHIFTE                      ((knh_token_t)42)
-#define TT_ADDE                         ((knh_token_t)43)
-#define TT_SUBE                         ((knh_token_t)44)
-#define TT_MULE                         ((knh_token_t)45)
-#define TT_DIVE                         ((knh_token_t)46)
-#define TT_MODE                         ((knh_token_t)47)
-#define TT_BITORE                       ((knh_token_t)48)
-#define TT_BITANDE                      ((knh_token_t)49)
-#define TT_ALTLET                       ((knh_token_t)50)
-#define TT_QUESTION                     ((knh_token_t)51)
-#define TT_ITR                          ((knh_token_t)52)
-#define TT_SUBSET                       ((knh_token_t)53)
-#define TT_OFFSET                       ((knh_token_t)54)
-#define TT_COLON                        ((knh_token_t)55)
-#define TT_ALT                          ((knh_token_t)56)
-#define TT_OR                           ((knh_token_t)57)
-#define TT_AND                          ((knh_token_t)58)
-#define TT_NOT                          ((knh_token_t)59)
-#define TT_INSTANCEOF                   ((knh_token_t)60)
-#define TT_ISA                          ((knh_token_t)61)
-#define TT_AS                           ((knh_token_t)62)
-#define TT_HAS                          ((knh_token_t)63)
-#define TT_IS                           ((knh_token_t)64)
-#define TT_TO                           ((knh_token_t)65)
-#define TT_EQ                           ((knh_token_t)66)
-#define TT_NEQ                          ((knh_token_t)67)
-#define TT_LT                           ((knh_token_t)68)
-#define TT_LTE                          ((knh_token_t)69)
-#define TT_GT                           ((knh_token_t)70)
-#define TT_GTE                          ((knh_token_t)71)
-#define TT_MATCH                        ((knh_token_t)72)
-#define TT_LOR                          ((knh_token_t)73)
-#define TT_FMT                          ((knh_token_t)74)
-#define TT_LSHIFT                       ((knh_token_t)75)
-#define TT_RSHIFT                       ((knh_token_t)76)
-#define TT_ADD                          ((knh_token_t)77)
-#define TT_SUB                          ((knh_token_t)78)
-#define TT_DIV                          ((knh_token_t)79)
-#define TT_MOD                          ((knh_token_t)80)
-#define TT_MUL                          ((knh_token_t)81)
-#define TT_LAND                         ((knh_token_t)82)
-#define TT_LNOT                         ((knh_token_t)83)
-#define TT_XOR                          ((knh_token_t)84)
-#define TT_NEXT                         ((knh_token_t)85)
-#define TT_PREV                         ((knh_token_t)86)
-#define TT_NEG                          ((knh_token_t)87)
-#define TT_NUM                          ((knh_token_t)88)
+#define TT_FUNCTION                     ((knh_token_t)9)
+#define TT_FORMAT                       ((knh_token_t)10)
+#define TT_RETURN                       ((knh_token_t)11)
+#define TT_MAPMAP                       ((knh_token_t)12)
+#define TT_WEAVE                        ((knh_token_t)13)
+#define TT_ASPECT                       ((knh_token_t)14)
+#define TT_BLOCK                        ((knh_token_t)15)
+#define TT_IF                           ((knh_token_t)16)
+#define TT_ELSE                         ((knh_token_t)17)
+#define TT_SWITCH                       ((knh_token_t)18)
+#define TT_CASE                         ((knh_token_t)19)
+#define TT_WHILE                        ((knh_token_t)20)
+#define TT_DO                           ((knh_token_t)21)
+#define TT_FOR                          ((knh_token_t)22)
+#define TT_FOREACH                      ((knh_token_t)23)
+#define TT_FROM                         ((knh_token_t)24)
+#define TT_WHERE                        ((knh_token_t)25)
+#define TT_BREAK                        ((knh_token_t)26)
+#define TT_CONTINUE                     ((knh_token_t)27)
+#define TT_TRY                          ((knh_token_t)28)
+#define TT_CATCH                        ((knh_token_t)29)
+#define TT_FINALLY                      ((knh_token_t)30)
+#define TT_THROW                        ((knh_token_t)31)
+#define TT_LOCAL                        ((knh_token_t)32)
+#define TT_PRINT                        ((knh_token_t)33)
+#define TT_ASSERT                       ((knh_token_t)34)
+#define TT_BRACE                        ((knh_token_t)35)
+#define TT_PARENTHESIS                  ((knh_token_t)36)
+#define TT_BRANCET                      ((knh_token_t)37)
+#define TT_DOTS                         ((knh_token_t)38)
+#define TT_SEMICOLON                    ((knh_token_t)39)
+#define TT_COMMA                        ((knh_token_t)40)
+#define TT_FUNCMAP                      ((knh_token_t)41)
+#define TT_LET                          ((knh_token_t)42)
+#define TT_LSHIFTE                      ((knh_token_t)43)
+#define TT_RSHIFTE                      ((knh_token_t)44)
+#define TT_ADDE                         ((knh_token_t)45)
+#define TT_SUBE                         ((knh_token_t)46)
+#define TT_MULE                         ((knh_token_t)47)
+#define TT_DIVE                         ((knh_token_t)48)
+#define TT_MODE                         ((knh_token_t)49)
+#define TT_BITORE                       ((knh_token_t)50)
+#define TT_BITANDE                      ((knh_token_t)51)
+#define TT_ALTLET                       ((knh_token_t)52)
+#define TT_QUESTION                     ((knh_token_t)53)
+#define TT_ITR                          ((knh_token_t)54)
+#define TT_SUBSET                       ((knh_token_t)55)
+#define TT_OFFSET                       ((knh_token_t)56)
+#define TT_COLON                        ((knh_token_t)57)
+#define TT_ALT                          ((knh_token_t)58)
+#define TT_OR                           ((knh_token_t)59)
+#define TT_AND                          ((knh_token_t)60)
+#define TT_NOT                          ((knh_token_t)61)
+#define TT_INSTANCEOF                   ((knh_token_t)62)
+#define TT_ISA                          ((knh_token_t)63)
+#define TT_AS                           ((knh_token_t)64)
+#define TT_HAS                          ((knh_token_t)65)
+#define TT_IS                           ((knh_token_t)66)
+#define TT_TO                           ((knh_token_t)67)
+#define TT_EQ                           ((knh_token_t)68)
+#define TT_NEQ                          ((knh_token_t)69)
+#define TT_LT                           ((knh_token_t)70)
+#define TT_LTE                          ((knh_token_t)71)
+#define TT_GT                           ((knh_token_t)72)
+#define TT_GTE                          ((knh_token_t)73)
+#define TT_MATCH                        ((knh_token_t)74)
+#define TT_LOR                          ((knh_token_t)75)
+#define TT_FMT                          ((knh_token_t)76)
+#define TT_LSHIFT                       ((knh_token_t)77)
+#define TT_RSHIFT                       ((knh_token_t)78)
+#define TT_ADD                          ((knh_token_t)79)
+#define TT_SUB                          ((knh_token_t)80)
+#define TT_DIV                          ((knh_token_t)81)
+#define TT_MOD                          ((knh_token_t)82)
+#define TT_MUL                          ((knh_token_t)83)
+#define TT_LAND                         ((knh_token_t)84)
+#define TT_LNOT                         ((knh_token_t)85)
+#define TT_XOR                          ((knh_token_t)86)
+#define TT_NEXT                         ((knh_token_t)87)
+#define TT_PREV                         ((knh_token_t)88)
+#define TT_NEG                          ((knh_token_t)89)
+#define TT_NUM                          ((knh_token_t)90)
 #define knh_Token_isNUM(tk_)            (SP(tk_)->tt == TT_NUM)
-#define TT_STR                          ((knh_token_t)89)
+#define TT_STR                          ((knh_token_t)91)
 #define knh_Token_isSTR(tk_)            (SP(tk_)->tt == TT_STR)
-#define TT_TSTR                         ((knh_token_t)90)
+#define TT_TSTR                         ((knh_token_t)92)
 #define knh_Token_isTSTR(tk_)           (SP(tk_)->tt == TT_TSTR)
-#define TT_EVAL                         ((knh_token_t)91)
+#define TT_EVAL                         ((knh_token_t)93)
 #define knh_Token_isEVAL(tk_)           (SP(tk_)->tt == TT_EVAL)
-#define TT_LABEL                        ((knh_token_t)92)
+#define TT_LABEL                        ((knh_token_t)94)
 #define knh_Token_isLABEL(tk_)          (SP(tk_)->tt == TT_LABEL)
-#define TT_METAN                        ((knh_token_t)93)
+#define TT_METAN                        ((knh_token_t)95)
 #define knh_Token_isMETAN(tk_)          (SP(tk_)->tt == TT_METAN)
-#define TT_PROPN                        ((knh_token_t)94)
+#define TT_PROPN                        ((knh_token_t)96)
 #define knh_Token_isPROPN(tk_)          (SP(tk_)->tt == TT_PROPN)
-#define TT_URN                          ((knh_token_t)95)
+#define TT_URN                          ((knh_token_t)97)
 #define knh_Token_isURN(tk_)            (SP(tk_)->tt == TT_URN)
-#define TT_MT                           ((knh_token_t)96)
+#define TT_MT                           ((knh_token_t)98)
 #define knh_Token_isMT(tk_)             (SP(tk_)->tt == TT_MT)
-#define TT_CONSTN                       ((knh_token_t)97)
+#define TT_CONSTN                       ((knh_token_t)99)
 #define knh_Token_isCONSTN(tk_)         (SP(tk_)->tt == TT_CONSTN)
-#define TT_TYPEN                        ((knh_token_t)98)
+#define TT_TYPEN                        ((knh_token_t)100)
 #define knh_Token_isTYPEN(tk_)          (SP(tk_)->tt == TT_TYPEN)
-#define TT_CMETHODN                     ((knh_token_t)99)
+#define TT_CMETHODN                     ((knh_token_t)101)
 #define knh_Token_isCMETHODN(tk_)       (SP(tk_)->tt == TT_CMETHODN)
-#define TT_NAME                         ((knh_token_t)100)
+#define TT_NAME                         ((knh_token_t)102)
 #define knh_Token_isNAME(tk_)           (SP(tk_)->tt == TT_NAME)
-#define TT_ERR                          ((knh_token_t)101)
+#define TT_ERR                          ((knh_token_t)103)
 #define knh_Token_isERR(tk_)            (SP(tk_)->tt == TT_ERR)
-#define TT_MN                           ((knh_token_t)102)
+#define TT_MN                           ((knh_token_t)104)
 #define knh_Token_isMN(tk_)             (SP(tk_)->tt == TT_MN)
-#define TT_FN                           ((knh_token_t)103)
+#define TT_FN                           ((knh_token_t)105)
 #define knh_Token_isFN(tk_)             (SP(tk_)->tt == TT_FN)
-#define TT_CID                          ((knh_token_t)104)
+#define TT_CID                          ((knh_token_t)106)
 #define knh_Token_isCID(tk_)            (SP(tk_)->tt == TT_CID)
-#define TT_MPR                          ((knh_token_t)105)
+#define TT_MPR                          ((knh_token_t)107)
 #define knh_Token_isMPR(tk_)            (SP(tk_)->tt == TT_MPR)
-#define TT_EOT                          ((knh_token_t)106)
+#define TT_EOT                          ((knh_token_t)108)
 #define knh_Token_isEOT(tk_)            (SP(tk_)->tt == TT_EOT)
-#define TT_CONST                        ((knh_token_t)107)
+#define TT_CONST                        ((knh_token_t)109)
 #define knh_Token_isCONST(tk_)          (SP(tk_)->tt == TT_CONST)
-#define TT_DEFVAL                       ((knh_token_t)108)
+#define TT_DEFVAL                       ((knh_token_t)110)
 #define knh_Token_isDEFVAL(tk_)         (SP(tk_)->tt == TT_DEFVAL)
-#define TT_SYSVAL                       ((knh_token_t)109)
+#define TT_SYSVAL                       ((knh_token_t)111)
 #define knh_Token_isSYSVAL(tk_)         (SP(tk_)->tt == TT_SYSVAL)
-#define TT_STACK                        ((knh_token_t)110)
+#define TT_STACK                        ((knh_token_t)112)
 #define knh_Token_isSTACK(tk_)          (SP(tk_)->tt == TT_STACK)
-#define TT_FIELD                        ((knh_token_t)111)
+#define TT_FIELD                        ((knh_token_t)113)
 #define knh_Token_isFIELD(tk_)          (SP(tk_)->tt == TT_FIELD)
-#define TT_GLOBAL                       ((knh_token_t)112)
+#define TT_GLOBAL                       ((knh_token_t)114)
 #define knh_Token_isGLOBAL(tk_)         (SP(tk_)->tt == TT_GLOBAL)
-#define TT_MEMBER                       ((knh_token_t)113)
+#define TT_MEMBER                       ((knh_token_t)115)
 #define knh_Token_isMEMBER(tk_)         (SP(tk_)->tt == TT_MEMBER)
-#define TT_CLASSID                      ((knh_token_t)114)
+#define TT_CLASSID                      ((knh_token_t)116)
 #define knh_Token_isCLASSID(tk_)        (SP(tk_)->tt == TT_CLASSID)
-#define TT_ASIS                         ((knh_token_t)115)
+#define TT_ASIS                         ((knh_token_t)117)
 #define knh_Token_isASIS(tk_)           (SP(tk_)->tt == TT_ASIS)
-#define TT_NOP                          ((knh_token_t)116)
+#define TT_NOP                          ((knh_token_t)118)
 #define knh_Token_isNOP(tk_)            (SP(tk_)->tt == TT_NOP)
-#define KNH_TOKEN_MAXSIZ                ((knh_token_t)117)
+#define KNH_TOKEN_MAXSIZ                ((knh_token_t)119)
 
 /* ------------------------------------------------------------------------ */
 #ifndef METHODN_opItr
@@ -304,7 +306,7 @@ extern "C" {
 #define STT_EXTENDS                     ((knh_stmt_t)14)
 #define STT_IMPLEMENTS                  ((knh_stmt_t)15)
 #define STT_METHOD                      ((knh_stmt_t)16)
-#define STT_CLOSURE                     ((knh_stmt_t)17)
+#define STT_FUNCTION                    ((knh_stmt_t)17)
 #define STT_FORMAT                      ((knh_stmt_t)18)
 #define STT_DECL                        ((knh_stmt_t)19)
 #define STT_RETURN                      ((knh_stmt_t)20)
@@ -339,15 +341,14 @@ extern "C" {
 #define STT_PCALL                       ((knh_stmt_t)49)
 #define STT_MT                          ((knh_stmt_t)50)
 #define STT_OP                          ((knh_stmt_t)51)
-#define STT_INVOKE                      ((knh_stmt_t)52)
-#define STT_PROCEED                     ((knh_stmt_t)53)
-#define STT_TRI                         ((knh_stmt_t)54)
-#define STT_ALT                         ((knh_stmt_t)55)
-#define STT_AND                         ((knh_stmt_t)56)
-#define STT_OR                          ((knh_stmt_t)57)
-#define STT_PRINT                       ((knh_stmt_t)58)
-#define STT_ASSERT                      ((knh_stmt_t)59)
-#define KNH_STMT_MAXSIZ                 ((knh_stmt_t)60)
+#define STT_PROCEED                     ((knh_stmt_t)52)
+#define STT_TRI                         ((knh_stmt_t)53)
+#define STT_ALT                         ((knh_stmt_t)54)
+#define STT_AND                         ((knh_stmt_t)55)
+#define STT_OR                          ((knh_stmt_t)56)
+#define STT_PRINT                       ((knh_stmt_t)57)
+#define STT_ASSERT                      ((knh_stmt_t)58)
+#define KNH_STMT_MAXSIZ                 ((knh_stmt_t)59)
 
 /* ------------------------------------------------------------------------ */
 
@@ -457,13 +458,13 @@ extern "C" {
 #define METHOD_instmt                   4
 
 /* ======================================================================== */
-/* [closure] */
-#define StmtCLOSURE_rtype(stmt)         DP(stmt)->tokens[0]
-#define CLOSURE_rtype                   0
-#define StmtCLOSURE_params(stmt)        DP(stmt)->stmts[1]
-#define CLOSURE_params                  1
-#define StmtCLOSURE_instmt(stmt)        DP(stmt)->stmts[2]
-#define CLOSURE_instmt                  2
+/* [function] */
+#define StmtFUNCTION_rtype(stmt)        DP(stmt)->tokens[0]
+#define FUNCTION_rtype                  0
+#define StmtFUNCTION_params(stmt)       DP(stmt)->stmts[1]
+#define FUNCTION_params                 1
+#define StmtFUNCTION_instmt(stmt)       DP(stmt)->stmts[2]
+#define FUNCTION_instmt                 2
 
 /* ======================================================================== */
 /* [format] */
@@ -701,11 +702,6 @@ extern "C" {
 #define StmtOP_args_size(stmt)          (DP(stmt)->size - 2)
 #define StmtOP_args(stmt,n)             DP(stmt)->terms[n-2]
 
-/* ======================================================================== */
-/* [invoke] */
-#define StmtINVOKE_func(stmt)           DP(stmt)->terms[0]
-#define INVOKE_func                     0
-
 /* ======================================================================== */
 /* [proceed] */
 #define StmtPROCEED_method(stmt)        DP(stmt)->tokens[0]
