@@ -1130,8 +1130,8 @@ static knh_MethodData_t MethodData[] = {
 	{knh__Object_opIsa, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_opIsa, 0, MFN_nBoolean_nClass, (void*)NULL},
 	{knh__Object_opTo, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_opTo, 0, MFN_nBoolean_nClass, (void*)NULL},
 	{knh__Object_getClass, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_getClass, 0, MFN_nClass, (void*)NULL},
-	{knh__Object_isNull, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_isNull, 0, MFN_nBoolean, (void*)NULL},
-	{knh__Object_isNotNull, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_isNotNull, 0, MFN_nBoolean, (void*)NULL},
+	{knh__Object_isNull, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_Object, METHODN_isNull, 0, MFN_nBoolean, (void*)NULL},
+	{knh__Object_isNotNull, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_Object, METHODN_isNotNull, 0, MFN_nBoolean, (void*)NULL},
 	{knh__Object_opItr, 0, CLASS_Object, METHODN_opItr, 0, MFN_iThis, (void*)NULL},
 	{knh_fmethod_movableText, 0, CLASS_Object, METHODN__s, 0, MFN_void_OutputStream_Any, (void*)knh_Object__s},
 	{knh_fmethod_movableText, 0, CLASS_Object, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Object__k},
@@ -1188,7 +1188,6 @@ static knh_MethodData_t MethodData[] = {
 	{knh__System_setOut, KNH_FLAG_MF_STATIC, CLASS_System, METHODN_setOut, 0, MFN_void_OutputStream, (void*)NULL},
 	{knh__System_getErr, KNH_FLAG_MF_STATIC, CLASS_System, METHODN_getErr, 0, MFN_nOutputStream, (void*)NULL},
 	{knh__System_setErr, KNH_FLAG_MF_STATIC, CLASS_System, METHODN_setStdErr, 0, MFN_void_OutputStream, (void*)NULL},
-	{knh__System_gc, KNH_FLAG_MF_STATIC, CLASS_System, METHODN_gc, 0, MFN_void, (void*)NULL},
 	{knh__System_exit, KNH_FLAG_MF_STATIC, CLASS_System, METHODN_exit, 0, MFN_void_Int, (void*)NULL},
 	{knh__System_hasDir, 0, CLASS_System, METHODN_hasDir, 0, MFN_nBoolean_nString, (void*)NULL},
 	{knh__System_hasFile, 0, CLASS_System, METHODN_hasFile, 0, MFN_nBoolean_nString, (void*)NULL},
@@ -1244,6 +1243,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh__Script_isStatement, 0, CLASS_Script, METHODN_isStatement, 0, MFN_nBoolean_nString, (void*)NULL},
 	{knh__Script_readLine, 0, CLASS_Script, METHODN_readLine, 0, MFN_String_String, (void*)NULL},
 	{knh__Script_addHistory, 0, CLASS_Script, METHODN_addHistory, 0, MFN_void_nString, (void*)NULL},
+	{knh__System_gc, KNH_FLAG_MF_STATIC, CLASS_System, METHODN_gc, 0, MFN_void, (void*)NULL},
 	{knh__Object_opInstanceof, 0, CLASS_Object, METHODN_opInstanceof, 0, MFN_Boolean_nClass, (void*)NULL},
 	{knh__Object_isRelease, 0, CLASS_Object, METHODN_isRelease, 0, MFN_nBoolean, (void*)NULL},
 	{knh__Object_isDebug, 0, CLASS_Object, METHODN_isDebug, 0, MFN_nBoolean, (void*)NULL},
