@@ -35,11 +35,6 @@
 extern "C" {
 #endif
 
-
-#ifndef KNH_ARRAY_INITSIZE
-#define KNH_ARRAY_INITSIZE  4
-#endif/*KNH_ARRAY_INITSIZE*/
-
 /* ======================================================================== */
 /* [new] */
 
@@ -51,9 +46,9 @@ METHOD knh__Array_new(Ctx *ctx, knh_sfp_t *sfp)
 	Array *o = (Array*)sfp[0].o;
 	size_t init = IS_NULL(sfp[1].o) ? KNH_ARRAY_INITSIZE: p_size(sfp[1]);
 	if(init > 0) {
-		o->list = knh_oarray_malloc(ctx, init, KNH_NULL);
-		o->size = 0;
+		knh_Array_grow(ctx, o, init, KNH_NULL);
 	}
+	o->size = 0;
 	KNH_RETURN(ctx, sfp, o);
 }
 
@@ -67,47 +62,12 @@ METHOD knh__Array_new__array(Ctx *ctx, knh_sfp_t *sfp)
 	knh_class_t p1 = ctx->tClass[knh_Object_cid(o)].p1;
 	Object *v = (p1 == CLASS_Any) ? KNH_NULL : konoha_getClassDefaultValue(ctx, p1);
 	if(init > 0) {
-		o->list = knh_oarray_malloc(ctx, init, v);
+		knh_Array_grow(ctx, o, init, v);
 		o->size = init;
 	}
 	KNH_RETURN(ctx, sfp, o);
 }
 
-/* ------------------------------------------------------------------------ */
-/* @method This! Array.new:array2D(Int! x, Int! y) @Private */
-
-METHOD knh__Array_new__array2D(Ctx *ctx, knh_sfp_t *sfp)
-{
-	Array *o = (Array*)sfp[0].o;
-	size_t init = p_size(sfp[1]) * p_size(sfp[2]);
-	knh_class_t p1 = ctx->tClass[knh_Object_cid(o)].p1;
-	Object *v = (p1 == CLASS_Any) ? KNH_NULL : konoha_getClassDefaultValue(ctx, p1);
-	if(init > 0) {
-		o->list = knh_oarray_malloc(ctx, init, v);
-		o->size = init;
-		knh_oarray_set_opsize(o->list, p_size(sfp[1]));
-	}
-	KNH_RETURN(ctx, sfp, o);
-}
-
-/* ------------------------------------------------------------------------ */
-/* @method This! Array.new:array3D(Int! x, Int! y, Int! z) @Private */
-
-METHOD knh__Array_new__array3D(Ctx *ctx, knh_sfp_t *sfp)
-{
-	Array *o = (Array*)sfp[0].o;
-	size_t init = p_size(sfp[1]) * p_size(sfp[2]) * p_size(sfp[3]);
-	knh_class_t p1 = ctx->tClass[knh_Object_cid(o)].p1;
-	Object *v = (p1 == CLASS_Any) ? KNH_NULL : konoha_getClassDefaultValue(ctx, p1);
-	if(init > 0) {
-		o->list = knh_oarray_malloc(ctx, init, v);
-		o->size = init;
-		knh_oarray_setop1(o->list, p_size(sfp[1]));
-		knh_oarray_setop2(o->list, p_size(sfp[2]));
-	}
-	KNH_RETURN(ctx, sfp, o);
-}
-
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] This! Array.new:init(Any1 value) @VARARGS */
 
@@ -116,6 +76,9 @@ METHOD knh__Array_new__init(Ctx *ctx, knh_sfp_t *sfp)
 	Array *o = (Array*)sfp[0].o;
 	knh_sfp_t *v = sfp + 1;
 	int i, ac = knh_sfp_argc(ctx, v);
+	if(ac > 0) {
+		knh_Array_grow(ctx, o, ac, KNH_NULL);
+	}
 	for(i = 0; i < ac; i++) {
 		knh_sfp_boxing(ctx, v + i);
 		knh_Array_add(ctx, o, v[i].o);
@@ -133,10 +96,9 @@ METHOD knh__Array_add(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
-		if(o->size == knh_oarray_capacity(o->list)) {
-			o->list = knh_oarray_grow(ctx, o->list);
+		if(o->size == o->capacity) {
+			knh_Array_grow(ctx, o, knh_array_newsize(o->capacity * 2, sizeof(Object*)), KNH_NULL);
 		}
-		KNH_ASSERT(o->size < knh_oarray_capacity(o->list));
 		knh_sfp_boxing(ctx, sfp + 1);
 		KNH_SETv(ctx, o->list[o->size], sfp[1].o);
 		o->size++;
@@ -162,7 +124,6 @@ METHOD knh__Array_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 }
 
 /* ======================================================================== */
-/* ------------------------------------------------------------------------ */
 /* @method Int! Array.opSize() */
 
 METHOD knh__Array_opSize(Ctx *ctx, knh_sfp_t *sfp)
@@ -181,28 +142,6 @@ METHOD knh__Array_get(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_RETURN(ctx, sfp, o->list[n2]);
 }
 
-/* ------------------------------------------------------------------------ */
-/* @method Any1 Array.get2D(Int! x, Int! y) */
-
-METHOD knh__Array_get2D(Ctx *ctx, knh_sfp_t *sfp)
-{
-	Array *o = (Array*)sfp[0].o;
-	size_t x = knh_oarray_opsize(o->list), y = o->size / x;
-	size_t n2 = knh_array_index(ctx, p_int(sfp[1]), x) + (knh_array_index(ctx, p_int(sfp[2]), y) * x);
-	KNH_RETURN(ctx, sfp, o->list[n2]);
-}
-
-/* ------------------------------------------------------------------------ */
-/* @method Any1 Array.get3D(Int! x, Int! y, Int! z) */
-
-METHOD knh__Array_get3D(Ctx *ctx, knh_sfp_t *sfp)
-{
-	Array *o = (Array*)sfp[0].o;
-	size_t n2 = knh_array_index(ctx, p_int(sfp[1]) +
-			(p_int(sfp[2]) * knh_oarray_op1(o->list)) + (p_int(sfp[3]) * knh_oarray_op1(o->list) * knh_oarray_op2(o->list)), o->size);
-	KNH_RETURN(ctx, sfp, o->list[n2]);
-}
-
 /* ------------------------------------------------------------------------ */
 /* @method void Array.set(Int! n, Any1 v) */
 
@@ -216,37 +155,6 @@ METHOD knh__Array_set(Ctx *ctx, knh_sfp_t *sfp)
 	}
 	KNH_RETURN_void(ctx, sfp);
 }
-
-/* ------------------------------------------------------------------------ */
-/* @method void Array.set2D(Int! x, Int! y, Any1 v) */
-
-METHOD knh__Array_set2D(Ctx *ctx, knh_sfp_t *sfp)
-{
-	Array *o = (Array*)sfp[0].o;
-	if(!knh_Object_isImmutable(o)) {
-		size_t x = knh_oarray_opsize(o->list), y = o->size / x;
-		size_t n2 = knh_array_index(ctx, p_int(sfp[1]), x) + (knh_array_index(ctx, p_int(sfp[2]), y) * x);
-		knh_sfp_boxing(ctx, sfp + 3);
-		KNH_SETv(ctx, o->list[n2], sfp[3].o);
-	}
-	KNH_RETURN_void(ctx, sfp);
-}
-
-/* ------------------------------------------------------------------------ */
-/* @method void Array.set3D(Int! x, Int! y, Int! z, Any1 v) */
-
-METHOD knh__Array_set3D(Ctx *ctx, knh_sfp_t *sfp)
-{
-	Array *o = (Array*)sfp[0].o;
-	if(!knh_Object_isImmutable(o)) {
-		size_t n2 = knh_array_index(ctx, p_int(sfp[1]) +
-				(p_int(sfp[2]) * knh_oarray_op1(o->list)) + (p_int(sfp[3]) * knh_oarray_op1(o->list) * knh_oarray_op2(o->list)), o->size);
-		knh_sfp_boxing(ctx, sfp + 3);
-		KNH_SETv(ctx, o->list[n2], sfp[4].o);
-	}
-	KNH_RETURN_void(ctx, sfp);
-}
-
 /* ------------------------------------------------------------------------ */
 /* @method void Array.setAll(Any1 v) */
 
@@ -263,23 +171,40 @@ METHOD knh__Array_setAll(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_RETURN_void(ctx, sfp);
 }
 
+/* ------------------------------------------------------------------------ */
+
+static
+Array *new_Array__subset(Ctx *ctx, Array *a, size_t s, size_t e)
+{
+	Array *newa = (Array*)new_Object_init(ctx, a->h.flag, a->h.cid, 0);
+	if(e < s) {
+		size_t t = s; s = e; e = t;
+	}
+	if(s < e) {
+		KNH_ASSERT(e <= a->size);
+		size_t i, newsize = e - s;
+		newa->list = (Object**)KNH_MALLOC(ctx, newsize * sizeof(Object*));
+		knh_memcpy(newa->list, &a->list[s], newsize * sizeof(Object*));
+#ifdef KNH_USING_RCGC
+		for(i = 0; i < newsize; i++) {
+			knh_Object_RCinc(newa->list[i]);
+		}
+#endif
+		newa->capacity = newsize;
+		newa->size = newsize;
+	}
+	return newa;
+}
+
 /* ------------------------------------------------------------------------ */
 /* @method This! Array.opSubset(Int s, Int e) @Debug */
 
 METHOD knh__Array_opSubset(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
-	if(o->size > 0) {
-		size_t s = IS_NULL(sfp[1].o) ? 0 : knh_array_index(ctx, p_int(sfp[1]), o->size);
-		size_t e = IS_NULL(sfp[2].o) ? (o->size) : knh_array_index(ctx, p_int(sfp[2]), o->size);
-		Array *newo = (Array*)new_Object_init(ctx, o->h.flag, o->h.cid, 0);
-		newo->list = knh_oarray_copy(ctx, o->list, s, e - s);
-		newo->size = e - s;
-		KNH_RETURN(ctx, sfp, newo);
-	}
-	else {
-		KNH_RETURN(ctx, sfp, new_Object_init(ctx, o->h.flag, o->h.cid, 0));
-	}
+	size_t s = IS_NULL(sfp[1].o) ? 0 : knh_array_index(ctx, p_int(sfp[1]), o->size);
+	size_t e = IS_NULL(sfp[2].o) ? (o->size) : knh_array_index(ctx, p_int(sfp[2]), o->size);
+	KNH_RETURN(ctx, sfp, new_Array__subset(ctx, o, s, e));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -288,17 +213,9 @@ METHOD knh__Array_opSubset(Ctx *ctx, knh_sfp_t *sfp)
 METHOD knh__Array_opSubsete(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
-	if(o->size > 0) {
-		size_t s = IS_NULL(sfp[1].o) ? 0 : knh_array_index(ctx, p_int(sfp[1]), o->size);
-		size_t e = IS_NULL(sfp[2].o) ? (o->size) : knh_array_index(ctx, p_int(sfp[2]), o->size) + 1;
-		Array *newo = (Array*)new_Object_init(ctx, o->h.flag, o->h.cid, 0);
-		newo->list = knh_oarray_copy(ctx, o->list, s, e - s);
-		newo->size = e - s;
-		KNH_RETURN(ctx, sfp, newo);
-	}
-	else {
-		KNH_RETURN(ctx, sfp, new_Object_init(ctx, o->h.flag, o->h.cid, 0));
-	}
+	size_t s = IS_NULL(sfp[1].o) ? 0 : knh_array_index(ctx, p_int(sfp[1]), o->size);
+	size_t e = IS_NULL(sfp[2].o) ? (o->size) : knh_array_index(ctx, p_int(sfp[2]) + 1, o->size) ;
+	KNH_RETURN(ctx, sfp, new_Array__subset(ctx, o, s, e));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -307,28 +224,10 @@ METHOD knh__Array_opSubsete(Ctx *ctx, knh_sfp_t *sfp)
 METHOD knh__Array_opOffset(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
-	if(o->size > 0) {
-		size_t s = IS_NULL(sfp[1].o) ? 0 : knh_array_index(ctx, p_int(sfp[1]), o->size);
-		knh_int_t offset = IS_NULL(sfp[2].o) ? 0 : p_int(sfp[2]);
-		Array *newo = (Array*)new_Object_init(ctx, o->h.flag, o->h.cid, 0);
-		if(offset == 0) {
-
-		}
-		else if(offset > 0){
-			newo->list = knh_oarray_copy(ctx, o->list, s, offset);
-			newo->size = offset;
-		}
-		else {
-			knh_int_t ss = s + offset;
-			if(ss < 0) ss = 0;
-			newo->list = knh_oarray_copy(ctx, o->list, ss, s - ss);
-			newo->size = s - ss;
-		}
-		KNH_RETURN(ctx, sfp, newo);
-	}
-	else {
-		KNH_RETURN(ctx, sfp, new_Object_init(ctx, o->h.flag, o->h.cid, 0));
-	}
+	size_t s = IS_NULL(sfp[1].o) ? 0 : knh_array_index(ctx, p_int(sfp[1]), o->size);
+	knh_int_t e = IS_NULL(sfp[1].o) ? o->size : s + p_int(sfp[2]);
+	if(e > o->size) e = o->size; else if(e < 0) e = 0;
+	KNH_RETURN(ctx, sfp, new_Array__subset(ctx, o, s, e));
 }
 
 /* ======================================================================== */
@@ -341,10 +240,9 @@ METHOD knh__Array_insert(Ctx *ctx, knh_sfp_t *sfp)
 	Array *o = (Array*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
 		size_t i, n = knh_array_index(ctx, p_int(sfp[1]), o->size);
-		if(o->size == knh_oarray_capacity(o->list)) {
-			o->list = knh_oarray_grow(ctx, o->list);
+		if(o->size == o->capacity) {
+			knh_Array_grow(ctx, o, knh_array_newsize(o->capacity * 2, sizeof(Object*)), KNH_NULL);
 		}
-		KNH_ASSERT(o->size < knh_oarray_capacity(o->list));
 		Object *temp = o->list[o->size];
 		o->size++;
 		for(i = o->size - 1; i > n ; i--) {
@@ -456,8 +354,7 @@ METHOD knh__Array_sort(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
-		knh_qsort(o->list, o->size, sizeof(Object*),
-					(int (*)(const void*, const void*))knh_Object_compareTo);
+		knh_qsort(o->list, o->size, sizeof(Object*), (int (*)(const void*, const void*))knh_Object_compareTo);
 	}
 	KNH_RETURN_void(ctx, sfp);
 }
@@ -608,6 +505,129 @@ Mapper *knh_tMapper_newArrayIterator(Ctx *ctx, knh_class_t acid, knh_class_t ici
 	return mpr;
 }
 
+/* ======================================================================== */
+/* [2d,3d] */
+/* @data */
+
+typedef struct {
+	size_t x;
+	size_t y;
+	size_t z;
+	size_t w;   /* unused */
+} knh_darray_t;
+
+/* ------------------------------------------------------------------------ */
+
+static
+void *knh_array_dmalloc(Ctx *ctx, size_t x, size_t y, size_t z, size_t usize)
+{
+	size_t capacity = x * y * z;
+	knh_darray_t *d = (knh_darray_t*)KNH_MALLOC(ctx, (capacity * usize) + sizeof(knh_darray_t));
+	d->x = x; d->y = y; d->z = z; d->w = d->x * d->y;
+	return (void*)(d+1);
+}
+
+/* ------------------------------------------------------------------------ */
+
+void knh_array_dfree(Ctx *ctx, void *ptr, size_t capacity, size_t usize)
+{
+	knh_darray_t *d = ((knh_darray_t*)ptr) - 1;
+	KNH_FREE(ctx, d, (capacity * usize) + sizeof(knh_darray_t));
+}
+
+/* ------------------------------------------------------------------------ */
+
+static
+void knh_ArrayDim_init(Ctx *ctx, Array *a, size_t x, size_t y, size_t z)
+{
+	knh_Array_setDim(a, 1);
+	a->list = (Object**)knh_array_dmalloc(ctx, x, y, z, sizeof(Object*));
+	a->capacity = x * y * z;
+	knh_class_t p1 = ctx->tClass[knh_Object_cid(a)].p1;
+	Object *v = (p1 == CLASS_Any) ? KNH_NULL : konoha_getClassDefaultValue(ctx, p1);
+	int i = 0;
+	for(i = 0; i < a->capacity; i++) {
+		KNH_INITv(a->list[i], v);
+	}
+	a->size = a->capacity;
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method This! Array.new:array2D(Int! x, Int! y) @Private */
+
+METHOD knh__Array_new__array2D(Ctx *ctx, knh_sfp_t *sfp)
+{
+	knh_ArrayDim_init(ctx, (Array*)sfp[0].o, p_size(sfp[1]), p_size(sfp[2]), 1);
+	KNH_RETURN(ctx, sfp, sfp[0].o);
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method This! Array.new:array3D(Int! x, Int! y, Int! z) @Private */
+
+METHOD knh__Array_new__array3D(Ctx *ctx, knh_sfp_t *sfp)
+{
+	knh_ArrayDim_init(ctx, (Array*)sfp[0].o, p_size(sfp[1]), p_size(sfp[2]), p_size(sfp[3]));
+	KNH_RETURN(ctx, sfp, sfp[0].o);
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method Any1 Array.get2D(Int! x, Int! y) */
+
+METHOD knh__Array_get2D(Ctx *ctx, knh_sfp_t *sfp)
+{
+	Array *o = (Array*)sfp[0].o;
+	knh_darray_t *d = ((knh_darray_t*)o->list) - 1;
+	size_t x = knh_array_index(ctx, p_int(sfp[1]), d->x);
+	size_t y = knh_array_index(ctx, p_int(sfp[2]), d->y);
+	KNH_RETURN(ctx, sfp, o->list[x + y * d->x]);
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method Any1 Array.get3D(Int! x, Int! y, Int! z) */
+
+METHOD knh__Array_get3D(Ctx *ctx, knh_sfp_t *sfp)
+{
+	Array *o = (Array*)sfp[0].o;
+	knh_darray_t *d = ((knh_darray_t*)o->list) - 1;
+	size_t x = knh_array_index(ctx, p_int(sfp[1]), d->x);
+	size_t y = knh_array_index(ctx, p_int(sfp[2]), d->y);
+	size_t z = knh_array_index(ctx, p_int(sfp[3]), d->z);
+	KNH_RETURN(ctx, sfp, o->list[x + y * d->x + z * d->w]);
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method void Array.set2D(Int! x, Int! y, Any1 v) */
+
+METHOD knh__Array_set2D(Ctx *ctx, knh_sfp_t *sfp)
+{
+	Array *o = (Array*)sfp[0].o;
+	if(!knh_Object_isImmutable(o)) {
+		knh_darray_t *d = ((knh_darray_t*)o->list) - 1;
+		size_t x = knh_array_index(ctx, p_int(sfp[1]), d->x);
+		size_t y = knh_array_index(ctx, p_int(sfp[2]), d->y);
+		knh_sfp_boxing(ctx, sfp + 3);
+		KNH_SETv(ctx, o->list[x + y * d->x], sfp[3].o);
+	}
+	KNH_RETURN_void(ctx, sfp);
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method void Array.set3D(Int! x, Int! y, Int! z, Any1 v) */
+
+METHOD knh__Array_set3D(Ctx *ctx, knh_sfp_t *sfp)
+{
+	Array *o = (Array*)sfp[0].o;
+	if(!knh_Object_isImmutable(o)) {
+		knh_darray_t *d = ((knh_darray_t*)o->list) - 1;
+		size_t x = knh_array_index(ctx, p_int(sfp[1]), d->x);
+		size_t y = knh_array_index(ctx, p_int(sfp[2]), d->y);
+		size_t z = knh_array_index(ctx, p_int(sfp[3]), d->z);
+		knh_sfp_boxing(ctx, sfp + 4);
+		KNH_SETv(ctx, o->list[x + y * d->x + z * d->w], sfp[4].o);
+	}
+	KNH_RETURN_void(ctx, sfp);
+}
+
 /* ------------------------------------------------------------------------ */
 
 #ifdef __cplusplus
