@@ -42,9 +42,8 @@ extern "C" {
 static
 METHOD knh__Delegate_scall(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_sfp_t *lsfp = KNH_LOCAL(ctx);
 	Closure* c = (Closure*)sfp[0].o;
-	int argc = lsfp - sfp - 1;
+	int argc = ctx->esp - sfp - 1;
 	DBG2_P("argc=%d", argc);
 	KNH_MOV(ctx, sfp[0].o, DP(c)->base);
 	KNH_SCALL(ctx, sfp, -1, DP(c)->mtd, argc);
@@ -60,6 +59,7 @@ METHOD knh__Closure_new(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_SETv(ctx, DP(sfp[0].cc)->base, sfp[1].o);
 	KNH_SETv(ctx, DP(sfp[0].cc)->mtd, sfp[2].mtd);
+	(sfp[0].cc)->finvoke_1 = knh__Delegate_scall;
 	KNH_RETURN(ctx, sfp, sfp[0].o);
 }
 
