@@ -177,38 +177,95 @@ void knh_write__flag(Ctx *ctx, OutputStream *w, knh_flag_t flag)
 }
 
 /* ------------------------------------------------------------------------ */
-
-void knh_write__type(Ctx *ctx, OutputStream *w, knh_type_t type)
-{
-	knh_write(ctx, w, B(CTXCLASSN(CLASS_type(type))));
-	knh_write(ctx, w, B(TYPEQ(type)));
-}
-
+/* language */
 /* ------------------------------------------------------------------------ */
 
-void knh_write__class(Ctx *ctx, OutputStream *w, knh_class_t cid)
+void knh_write_cid(Ctx *ctx, OutputStream *w, knh_class_t cid)
 {
 	knh_write(ctx, w, B(CTXCLASSN(cid)));
 }
 
 /* ------------------------------------------------------------------------ */
 
-void knh_write__expt(Ctx *ctx, OutputStream *w, knh_expt_t cid)
+#define _knh_write_fn(ctx, w, fn)   knh_write__s(ctx, w, FIELDN(fn))
+
+void knh_write_mn(Ctx *ctx, OutputStream *w, knh_methodn_t mn)
 {
-	TODO();
-	//knh_write(ctx, w, B(CLASSN(cid)));
+	char *name = FIELDN(METHODN_TOFIELDN(mn));
+	if(METHODN_IS_MOVTEXT(mn)) {
+		knh_putc(ctx, w, '%');
+	}
+	else if(METHODN_IS_GETTER(mn)) {
+		knh_write(ctx, w, STEXT("get"));
+		if(islower(name[0])) {
+			knh_putc(ctx, w, toupper(name[0])); name++;
+		}
+	}
+	else if(METHODN_IS_SETTER(mn)) {
+		knh_write(ctx, w, STEXT("set"));
+		if(islower(name[0])) {
+			knh_putc(ctx, w, toupper(name[0])); name++;
+		}
+	}
+	knh_write__s(ctx, w, name);
 }
 
 /* ------------------------------------------------------------------------ */
 
-void knh_write__mn(Ctx *ctx, OutputStream *w, knh_methodn_t mn)
+void knh_write_cidmn(Ctx *ctx, OutputStream *w, knh_class_t cid, knh_methodn_t mn)
 {
-	char buf[CLASSNAME_BUFSIZ];
-	knh_format_methodn(ctx, buf, sizeof(buf), mn);
-	knh_write__s(ctx, w, buf);
+	knh_write_cid(ctx, w, cid);
+	knh_putc(ctx, w, '.');
+	knh_write_mn(ctx, w, mn);
 }
 
-#define _knh_write__fn(ctx, w, fn)   knh_write__s(ctx, w, FIELDN(fn))
+/* ------------------------------------------------------------------------ */
+
+void knh_write_type(Ctx *ctx, OutputStream *w, knh_type_t type)
+{
+	if(type == TYPE_void) {
+		knh_write(ctx, w, STEXT("void"));
+		return;
+	}
+
+	knh_class_t cid = CLASS_type(type);
+	KNH_ASSERT_cid(cid);
+	char *cname = CTXCLASSN(cid);
+	if(type == NNTYPE_Int || type == NNTYPE_Float || type == NNTYPE_Boolean) {
+		knh_putc(ctx, w, tolower(cname[0]));
+		knh_write__s(ctx, w, cname + 1);
+		return;
+	}
+	knh_write__s(ctx, w, cname);
+	if(IS_NNTYPE(type)) {
+		knh_putc(ctx, w, '!');
+	}
+}
+
+
+/* ------------------------------------------------------------------------ */
+
+void knh_write_fline(Ctx *ctx, OutputStream *w, char *file, int line)
+{
+	if(line == 0) {
+		knh_write(ctx, w, STEXT("(unknown:0)"));
+	}
+	else {
+		knh_putc(ctx, w, '(');
+		knh_write__s(ctx, w, file);
+		knh_putc(ctx, w, ':');
+		knh_write__i(ctx, w, line);
+		knh_putc(ctx, w, ')');
+	}
+}
+
+///* ------------------------------------------------------------------------ */
+//
+//void knh_write__expt(Ctx *ctx, OutputStream *w, knh_expt_t cid)
+//{
+//	TODO();
+//	//knh_write(ctx, w, B(CLASSN(cid)));
+//}
 
 /* ======================================================================== */
 /* [String] */
@@ -287,15 +344,15 @@ KNHAPI(void) knh_printf(Ctx *ctx, OutputStream *w, char *fmt, ...)
 					break;
 
 				case 'M':
-					knh_write__mn(ctx, w, (knh_methodn_t)va_arg(args, int));
+					knh_write_mn(ctx, w, (knh_methodn_t)va_arg(args, int));
 					break;
 
 				case 'C':
-					knh_write__class(ctx, w, (knh_class_t)va_arg(args, int));
+					knh_write_cid(ctx, w, (knh_class_t)va_arg(args, int));
 					break;
 
 				case 'T':
-					knh_write__type(ctx, w, (knh_methodn_t)va_arg(args, int));
+					knh_write_type(ctx, w, (knh_methodn_t)va_arg(args, int));
 					break;
 
 				case 'B':
@@ -338,139 +395,140 @@ void konoha_setverbose(int v)
 
 KNHAPI(void) konoha_says(Ctx *ctx, int type, char *fmt, ...)
 {
-	int ch;
-	char *c = fmt;
-	va_list args;
-	if(ctx == NULL) {
-		FILE *fp = stderr;
-		if(type == KONOHA_NOTICE && verbose != 0) {
-			return;
-		}
-		fprintf(fp, "[KONOHA] ");
-		va_start(args , fmt);
-		while((ch = *c) != '\0') {
-			c++;
-			if(ch == '\\') {
-				ch = *c++;
-				switch(ch) {
-				case '\0' : return ;
-				case 'n': fprintf(fp, KONOHA_OS_LINEFEED); break;
-				case 't': fputc('\t', fp); break;
-				default:
-					fputc('\\', fp);
-					fputc(ch, fp);
-				}
-			}
-			else if(ch == '%') {
-				ch = *c++;
-				switch(ch) {
-				case '\0' : return ;
-				case 'd':
-					fprintf(fp, KNH_INT_FMT, (knh_int_t)va_arg(args, knh_int_t));
-					break;
-
-				case 'u':
-					fprintf(fp, KNH_UINT_FMT, (knh_uint_t)va_arg(args, knh_uint_t));
-					break;
-
-				case 'f':
-					fprintf(fp, "%f", (double)va_arg(args, double));
-					break;
-
-				case 's':
-					fprintf(fp, "%s", (char*)va_arg(args, char*));
-					break;
-
-				case 'O':
-					fprintf(fp, "OBJ(cid=%d)", (int)knh_Object_cid((Object*)va_arg(args, Object*)));
-					break;
-
-				case 'p':
-					fprintf(fp, "%p", (void*)va_arg(args, void*));
-						break;
-
-				default:
-					fputc('%', fp);
-					fputc(ch, fp);
-				}
-			}
-			else if(ch == 0) {
-				return;
-			}
-			else {
-				fputc(ch, fp);
-			}
-		} /* while */
-		fprintf(fp, KONOHA_OS_LINEFEED);
-	}
-	else {
-#ifndef KNH_DBGMODE
-		if(type == KONOHA_NOTICE && !knh_Context_isVerbose(ctx)) {
-			return;
-		}
-#endif
-		OutputStream *w = KNH_STDOUT;
-		knh_Context__s(ctx, (Context*)ctx, w, (String*)KNH_NULL);
-		knh_putc(ctx, w, ' ');
-		va_start(args , fmt);
-		while((ch = *c) != '\0') {
-			c++;
-			if(ch == '\\') {
-				ch = *c++;
-				switch(ch) {
-				case '\0' : return ;
-				case 'n':
-					knh_write_EOL(ctx, w); break;
-				case 't':
-					knh_write_TAB(ctx, w); break;
-				default:
-					knh_putc(ctx, w, '\\');
-					knh_putc(ctx, w, ch);
-				}
-			}
-			else if(ch == '%') {
-				ch = *c++;
-				switch(ch) {
-					case '\0' : return ;
-					case 'd':
-						knh_write__i(ctx, w, (knh_int_t)va_arg(args, knh_int_t));
-						break;
-
-					case 'u':
-						knh_write__u(ctx, w, (knh_uint_t)va_arg(args, knh_uint_t));
-						break;
-
-					case 'f':
-						knh_write__f(ctx, w, (knh_float_t)va_arg(args, double));
-						break;
-
-					case 's':
-						knh_write__s(ctx, w, (char*)va_arg(args, char*));
-						break;
-
-					case 'p':
-						knh_write__p(ctx, w, (void*)va_arg(args, void*));
-						break;
-
-					case 'O':
-						knh_write__O(ctx, w, (Object*)va_arg(args, Object*));
-						break;
-
-					default:
-						knh_putc(ctx, w, '%');
-						knh_putc(ctx, w, ch);
-				}
-			}
-			else if(ch == 0) {
-				return;
-			}
-			else {
-				knh_putc(ctx, w, ch);
-			}
-		} /* while */
-		knh_write_EOL(ctx, w);
-	}
-	va_end(args);
+	TODO();
+//	int ch;
+//	char *c = fmt;
+//	va_list args;
+//	if(ctx == NULL) {
+//		FILE *fp = stderr;
+//		if(type == KONOHA_NOTICE && verbose != 0) {
+//			return;
+//		}
+//		fprintf(fp, "[KONOHA] ");
+//		va_start(args , fmt);
+//		while((ch = *c) != '\0') {
+//			c++;
+//			if(ch == '\\') {
+//				ch = *c++;
+//				switch(ch) {
+//				case '\0' : return ;
+//				case 'n': fprintf(fp, KONOHA_OS_LINEFEED); break;
+//				case 't': fputc('\t', fp); break;
+//				default:
+//					fputc('\\', fp);
+//					fputc(ch, fp);
+//				}
+//			}
+//			else if(ch == '%') {
+//				ch = *c++;
+//				switch(ch) {
+//				case '\0' : return ;
+//				case 'd':
+//					fprintf(fp, KNH_INT_FMT, (knh_int_t)va_arg(args, knh_int_t));
+//					break;
+//
+//				case 'u':
+//					fprintf(fp, KNH_UINT_FMT, (knh_uint_t)va_arg(args, knh_uint_t));
+//					break;
+//
+//				case 'f':
+//					fprintf(fp, "%f", (double)va_arg(args, double));
+//					break;
+//
+//				case 's':
+//					fprintf(fp, "%s", (char*)va_arg(args, char*));
+//					break;
+//
+//				case 'O':
+//					fprintf(fp, "OBJ(cid=%d)", (int)knh_Object_cid((Object*)va_arg(args, Object*)));
+//					break;
+//
+//				case 'p':
+//					fprintf(fp, "%p", (void*)va_arg(args, void*));
+//						break;
+//
+//				default:
+//					fputc('%', fp);
+//					fputc(ch, fp);
+//				}
+//			}
+//			else if(ch == 0) {
+//				return;
+//			}
+//			else {
+//				fputc(ch, fp);
+//			}
+//		} /* while */
+//		fprintf(fp, KONOHA_OS_LINEFEED);
+//	}
+//	else {
+//#ifndef KNH_DBGMODE
+//		if(type == KONOHA_NOTICE && !knh_Context_isVerbose(ctx)) {
+//			return;
+//		}
+//#endif
+//		OutputStream *w = KNH_STDOUT;
+//		knh_Context__s(ctx, (Context*)ctx, w, (String*)KNH_NULL);
+//		knh_putc(ctx, w, ' ');
+//		va_start(args , fmt);
+//		while((ch = *c) != '\0') {
+//			c++;
+//			if(ch == '\\') {
+//				ch = *c++;
+//				switch(ch) {
+//				case '\0' : return ;
+//				case 'n':
+//					knh_write_EOL(ctx, w); break;
+//				case 't':
+//					knh_write_TAB(ctx, w); break;
+//				default:
+//					knh_putc(ctx, w, '\\');
+//					knh_putc(ctx, w, ch);
+//				}
+//			}
+//			else if(ch == '%') {
+//				ch = *c++;
+//				switch(ch) {
+//					case '\0' : return ;
+//					case 'd':
+//						knh_write__i(ctx, w, (knh_int_t)va_arg(args, knh_int_t));
+//						break;
+//
+//					case 'u':
+//						knh_write__u(ctx, w, (knh_uint_t)va_arg(args, knh_uint_t));
+//						break;
+//
+//					case 'f':
+//						knh_write__f(ctx, w, (knh_float_t)va_arg(args, double));
+//						break;
+//
+//					case 's':
+//						knh_write__s(ctx, w, (char*)va_arg(args, char*));
+//						break;
+//
+//					case 'p':
+//						knh_write__p(ctx, w, (void*)va_arg(args, void*));
+//						break;
+//
+//					case 'O':
+//						knh_write__O(ctx, w, (Object*)va_arg(args, Object*));
+//						break;
+//
+//					default:
+//						knh_putc(ctx, w, '%');
+//						knh_putc(ctx, w, ch);
+//				}
+//			}
+//			else if(ch == 0) {
+//				return;
+//			}
+//			else {
+//				knh_putc(ctx, w, ch);
+//			}
+//		} /* while */
+//		knh_write_EOL(ctx, w);
+//	}
+//	va_end(args);
 }
 
 /* ------------------------------------------------------------------------ */
