@@ -153,45 +153,54 @@ String *new_StringX__fast(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orig
 
 String *new_StringX__FormatException(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orign)
 {
-	Bytes *ba = knh_Context_openBConvBuf(ctx);
-	knh_Bytes_write(ctx, ba, STEXT("Format!!: "));
-	knh_Bytes_write(ctx, ba, B(CLASSN(cid)));
-	knh_Bytes_write(ctx, ba, STEXT("('"));
-	knh_Bytes_write(ctx, ba, t);
-	knh_Bytes_write(ctx, ba, STEXT(")'"));
-	{
-		String *s = (String*)new_Nue__b(ctx, knh_Bytes_tobytes(ba));
-		knh_Bytes_clear(ba);
-		return s;
-	}
+	TODO();
+//	Bytes *ba = knh_Context_openBConvBuf(ctx);
+//	knh_Bytes_write(ctx, ba, STEXT("Format!!: "));
+//	knh_Bytes_write(ctx, ba, B(CLASSN(cid)));
+//	knh_Bytes_write(ctx, ba, STEXT("('"));
+//	knh_Bytes_write(ctx, ba, t);
+//	knh_Bytes_write(ctx, ba, STEXT(")'"));
+//	{
+//		String *s = (String*)new_Nue__b(ctx, knh_Bytes_tobytes(ba));
+//		knh_Bytes_clear(ba, 0);
+//		return s;
+//	}
+	return TS_EMPTY;
 }
 
 /* ------------------------------------------------------------------------ */
 
 String *new_StringX(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orign)
 {
-	KNH_ASSERT_cid(cid);
-	{
-		StringUnit *u = (StringUnit*)ctx->tClass[cid].cspec;
-		KNH_ASSERT(IS_StringUnit(u));
-		if(DP(u)->fbconv != NULL) {
-			Bytes *ba = knh_Context_openBConvBuf(ctx);
-			size_t n = DP(u)->fbconv(ctx, DP(u)->bconv, t, ba);
-			if(n == ((size_t)-1)) {
-				knh_Bytes_clear(ba);
-				return new_StringX__FormatException(ctx, cid, t, orign);
-			}
-			else {
-				knh_bytes_t newt = knh_Bytes_tobytes(ba);
-				if(knh_bytes_strcmp(t, newt) != 0) {
-					String *s = DP(u)->fnew(ctx, cid, newt, NULL);
-					knh_Bytes_clear(ba);
-					return s;
-				}
-			}
-		}
-		return DP(u)->fnew(ctx, cid, t, orign);
+	if(cid == CLASS_String) {
+		return new_String(ctx, t, orign);
 	}
+	else {
+		KNH_ASSERT_cid(cid);
+		TODO();
+		return new_String(ctx, t, orign);
+	}
+//	StringUnit *u = (StringUnit*)ctx->tClass[cid].cspec;
+//	KNH_ASSERT(IS_StringUnit(u));
+//		if(DP(u)->fbconv != NULL) {
+//		return new_String__fcnv(ctx, DP(u)->)
+//		Bytes *ba = knh_Context_openBConvBuf(ctx);
+//			size_t n = DP(u)->fbconv(ctx, DP(u)->bconv, t, ba);
+//			if(n == ((size_t)-1)) {
+//				knh_Bytes_clear(ba, 0);
+//				return new_StringX__FormatException(ctx, cid, t, orign);
+//			}
+//			else {
+//				knh_bytes_t newt = knh_Bytes_tobytes(ba);
+//				if(knh_bytes_strcmp(t, newt) != 0) {
+//					String *s = DP(u)->fnew(ctx, cid, newt, NULL);
+//					knh_Bytes_clear(ba, 0);
+//					return s;
+//				}
+//			}
+//		}
+//		return DP(u)->fnew(ctx, cid, t, orign);
+//	}
 }
 
 /* ------------------------------------------------------------------------ */
