@@ -750,7 +750,7 @@ void KNH_ASM_CALL(Ctx *ctx, Asm *abr, knh_type_t reqt, int sfpidx, Token *tkb, s
 	Method *mtd = DP(tkb)->mtd;
 	knh_type_t rtype = CLASS_Any;
 	if(IS_Method(mtd)) {
-		if(knh_Method_isFinal(mtd)) {
+		if(knh_Method_isFinal(mtd) || knh_Method_isConstructor(ctx, mtd)) {
 			KNH_ASM_SCALL_(ctx, abr, sfpidx, args + 2, UP(mtd));
 		}
 		else {
@@ -763,7 +763,7 @@ void KNH_ASM_CALL(Ctx *ctx, Asm *abr, knh_type_t reqt, int sfpidx, Token *tkb, s
 		}
 	}
 	else if(SP(tkb)->tt == TT_MN) {
-		KNH_ASM_ACALL_(ctx, abr, sfpidx, args + 2, DP(tkb)->mn, reqt);
+		KNH_ASM_ACALL_(ctx, abr, sfpidx, args + 2, DP(tkb)->mn);
 		if(IS_NNTYPE(reqt) && !IS_NNTYPE(rtype)) {
 			KNH_ASM_ISNULL_(ctx, abr, sfpidx);
 			knh_rtti_nullChecked(abr, sfpidx);
@@ -1430,8 +1430,15 @@ void knh_StmtCALL_asm(Ctx *ctx, Stmt *stmt, Asm *abr, knh_type_t reqt, int sfpid
 	int local = ASML(abr, sfpidx);
 	Method *mtd = DP(DP(stmt)->tokens[0])->mtd;
 	knh_class_t cid = TERMs_getcid(stmt, 1);
-
 	size_t i;
+	/* UNTYPED CLOSURE */
+	if(cid == CLASS_Closure && IS_Method(mtd) && DP(mtd)->mn == METHODN_invoke) {
+		for(i = 1; i < DP(stmt)->size; i++) {
+			TERMs_asm(ctx, stmt, i, abr, TYPE_Any, local + i);
+		}
+		KNH_ASM_AINVOKE_(ctx, abr, sfi_(local), (knh_ushort_t)DP(stmt)->size, UP(mtd));
+		return;
+	}
 	/* PEEPHOLE */
 	if(IS_Method(mtd) && knh_Method_isFinal(mtd) && TERMs_isSTACK(stmt, 1)) {
 		int a = DP(DP(stmt)->tokens[1])->index;
