@@ -1647,7 +1647,7 @@ static Term *new_TermEXPR(Ctx *ctx, knh_tokens_t *tc, int lr)
 		if(DP(ts[oc])->tt_next == TT_PARENTHESIS) {
 			if(DP(ts[fc])->tt_next == TT_BRACE) {  /* @TEST Class (a,b) { ... } */
 				tc->c = oc;
-				stmt = new_Stmt(ctx, 0, STT_CLOSURE);
+				stmt = new_Stmt(ctx, 0, STT_FUNCTION);
 				knh_Stmt_add_TYPEN(ctx, stmt, tc);
 				knh_Stmt_add_PARAMs(ctx, stmt, tc);
 				knh_Stmt_add_STMT1(ctx, stmt, tc);
