@@ -276,10 +276,10 @@ knh_bool_t knh_Bytes_isTripleQuote(Bytes *o, knh_int_t ch)
 /* [Token] */
 
 static
-Token *new_Token__buffer(Ctx *ctx, knh_token_t tt, knh_wbuf_t tbuf, InputStream *in)
+Token *new_Token__buffer(Ctx *ctx, knh_token_t tt, knh_cwb_t tbuf, InputStream *in)
 {
 	Token *o = new_Token(ctx, 0, DP(in)->fileid, DP(in)->line, tt);
-	knh_bytes_t t = knh_wbuf_tobytes(tbuf);
+	knh_bytes_t t = knh_cwb_tobytes(tbuf);
 	//DBG2_P("tt=%s, '%s', len=%d", knh_token_tochar(tt), t.buf, t.len);
 
 	if(tt == TT_METAN && islower(t.buf[0])) {
@@ -296,7 +296,7 @@ Token *new_Token__buffer(Ctx *ctx, knh_token_t tt, knh_wbuf_t tbuf, InputStream
 		else {
 			KNH_SETv(ctx, DP(o)->data, new_String__bconv(ctx, t, DP(in)->bconv));
 		}
-		knh_wbuf_clear(tbuf);
+		knh_cwb_clear(tbuf);
 	}
 	return o;
 }
@@ -356,9 +356,9 @@ void knh_Token_padd(Ctx *ctx, Token *ptk, int *BOL, Token *tk)
 /* ------------------------------------------------------------------------ */
 
 static
-void knh_Token_add_space(Ctx *ctx, Token *tk, int *BOL, knh_wbuf_t tbuf, InputStream *in)
+void knh_Token_add_space(Ctx *ctx, Token *tk, int *BOL, knh_cwb_t tbuf, InputStream *in)
 {
-	knh_bytes_t t = knh_wbuf_tobytes(tbuf);
+	knh_bytes_t t = knh_cwb_tobytes(tbuf);
 	if(t.len == 0) return;
 
 	Token *tkp = knh_Token_tokens_lastNULL(tk);
@@ -390,7 +390,7 @@ void knh_Token_add_space(Ctx *ctx, Token *tk, int *BOL, knh_wbuf_t tbuf, InputSt
 	knh_Token_padd(ctx, tk, BOL, new_Token__parse(ctx, 0, in, t));
 
 	L_CLEAR:;
-	knh_wbuf_clear(tbuf);
+	knh_cwb_clear(tbuf);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -406,9 +406,9 @@ void knh_Token_addTypeParam(Ctx *ctx, Token *tkt, Array *a, size_t s)
 	return ;
 
 	L_PASS2:;
-	knh_wbuf_t wbuf = knh_Context_wbuf(ctx);
-	knh_write(ctx, wbuf.w, knh_Token_tobytes(ctx, tkt));
-	knh_putc(ctx, wbuf.w, '<');
+	knh_cwb_t cwb = new_cwb(ctx);
+	knh_write(ctx, cwb.w, knh_Token_tobytes(ctx, tkt));
+	knh_putc(ctx, cwb.w, '<');
 	knh_Array_remove(ctx, a, s);
 	i = s;
 	while(1) {
@@ -427,12 +427,69 @@ void knh_Token_addTypeParam(Ctx *ctx, Token *tkt, Array *a, size_t s)
 			}
 			break;
 		}
-		knh_write(ctx, wbuf.w, knh_Token_tobytes(ctx, tk));
+		knh_write(ctx, cwb.w, knh_Token_tobytes(ctx, tk));
 		knh_Array_remove(ctx, a, i);
 	}
-	knh_putc(ctx, wbuf.w, '>');
-	KNH_SETv(ctx, DP(tkt)->data, new_String__wbuf(ctx, wbuf));
+	knh_putc(ctx, cwb.w, '>');
+	KNH_SETv(ctx, DP(tkt)->data, new_String__cwb(ctx, cwb));
+}
 
+/* ------------------------------------------------------------------------ */
+
+static
+void knh_write_tktype(Ctx *ctx, OutputStream *w, Token *tk)
+{
+	if(knh_Token_isExceptionType(tk)) {
+		knh_write(ctx, w, STEXT("Exception"));
+	}
+	else {
+		knh_write(ctx, w, knh_Token_tobytes(ctx, tk));
+	}
+	if(knh_Token_isIteratorType(tk)) {
+		knh_write(ctx, w, STEXT(".."));
+		return;
+	}
+	if(knh_Token_isArrayType(tk)) {
+		knh_write(ctx, w, STEXT("[]"));
+	}
+	if(knh_Token_isNotNullType(tk)) {
+		knh_putc(ctx, w, '!');
+	}
+}
+
+/* ------------------------------------------------------------------------ */
+
+static
+int knh_Token_toClosureType(Ctx *ctx, Token *tkt, Token *tkp)
+{
+	knh_tokens_t tc ;
+	knh_Token_tc(tkp, &tc);
+	knh_cwb_t cwb = new_cwb(ctx);
+	knh_write_tktype(ctx, cwb.w, tkt);
+	knh_putc(ctx, cwb.w, '(');
+	int i, c = 0;
+	for(i = 0; i < tc.e; i++) {
+		if(SP(tc.ts[i])->tt == TT_COMMA) continue;
+		if(SP(tc.ts[i])->tt != TT_TYPEN) {
+			knh_cwb_clear(cwb);
+			return 0;
+		}
+		if(c > 0) knh_putc(ctx, cwb.w, ',');
+		knh_write_tktype(ctx, cwb.w, tc.ts[i]);
+		c++;
+	}
+	if(c > 3) {
+		KNH_SETv(ctx, DP(tkt)->data, ctx->tClass[CLASS_Closure].sname);
+		knh_cwb_clear(cwb);
+		return 1;
+	}
+	if(tc.e == 0) {
+		knh_write(ctx, cwb.w, STEXT("void"));
+	}
+	knh_putc(ctx, cwb.w, ')');
+	KNH_SETv(ctx, DP(tkt)->data, new_String__cwb(ctx, cwb));
+	//DBG2_P("closure='%s'", knh_String_tochar(DP(tkt)->text));
+	return 1;
 }
 
 /* ------------------------------------------------------------------------ */
@@ -447,9 +504,14 @@ void knh_Token_join(Ctx *ctx, Token *o)
 			Token *tk = (Token*)knh_Array_n(a, i);
 			if(SP(tk)->tt == TT_TYPEN) {
 				Token *tkn = (Token*)knh_Array_n(a, i+1);
-				if(SP(tkn)->tt == TT_LT) {
+				if(SP(tkn)->tt == TT_LT) {  /* T<T> */
 					knh_Token_addTypeParam(ctx, tk, a, i+1);
 				}
+				if(SP(tkn)->tt == TT_PARENTHESIS) {
+					if(knh_Token_toClosureType(ctx, tk, tkn)) {
+						knh_Array_remove(ctx, a, i+1);
+					}
+				}
 				if(SP(tkn)->tt == TT_BRANCET && IS_NULL(DP(tkn)->data)) {
 					knh_Token_setArrayType(tk, 1);
 					DP(tk)->tt_next = DP(tkn)->tt_next;
@@ -589,7 +651,7 @@ void knh_InputStream_skipBLOCK(Ctx *ctx, InputStream *in, int prev, Token *tk)
 
 void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 {
-	knh_wbuf_t tbuf = knh_Context_wbuf(ctx);
+	knh_cwb_t tbuf = new_cwb(ctx);
 	int ch, prev=0, indent = 0, pindent, BOL = 0;
 	Token *tks[TKSTACK_MAXSIZ] = {NULL};
 	Token *blocktk = NULL;
@@ -803,7 +865,7 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 
 		case ':':
 			ch = knh_InputStream_getc(ctx, in);
-			if(knh_wbuf_size(tbuf) == 0) {
+			if(knh_cwb_size(tbuf) == 0) {
 				if(ch == ' ' || ch == '\n' || ch == '\t' || ch == '\r' || ch == ';') {
 					knh_Bytes_putc(ctx, tbuf.ba, ':');
 					knh_Token_add_space(ctx, tks[tkl], &BOL, tbuf, in);
@@ -830,7 +892,7 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 
 		case '1': case '2': case '3': case '4': case '5':
 		case '6': case '7': case '8': case '9': case '0':
-			if(knh_wbuf_size(tbuf) == 0) {
+			if(knh_cwb_size(tbuf) == 0) {
 				knh_Bytes_putc(ctx, tbuf.ba, ch);
 				goto NUM_PART;
 			}
@@ -933,7 +995,7 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 	{
 		while((ch = knh_InputStream_getc(ctx, in)) != EOF) {
 			OP_PART_INLOOP:;
-			knh_bytes_t top = knh_wbuf_tobytes(tbuf);
+			knh_bytes_t top = knh_cwb_tobytes(tbuf);
 			if(knh_bytes_istoken(top, ch)) {
 				knh_Bytes_putc(ctx, tbuf.ba, ch);
 			}
