@@ -47,6 +47,7 @@ static char* knh_token_array_tochar[] = {
     "extends",  /* extends */ 
     "implements",  /* implements */ 
     "method",  /* method */ 
+    "function",  /* function */ 
     "format",  /* format */ 
     "return",  /* return */ 
     "mapmap",  /* mapmap */ 
@@ -78,6 +79,7 @@ static char* knh_token_array_tochar[] = {
     "...",  /* DOTS */ 
     ";",  /* SEMICOLON */ 
     ",",  /* COMMA */ 
+    "=>",  /* FUNCMAP */ 
     "=",  /* LET */ 
     "<<=",  /* lshifte */ 
     ">>=",  /* rshifte */ 
@@ -176,6 +178,7 @@ static knh_methodn_t knh_token_array_tomethodn[] = {
     METHODN_NONAME,  /* extends */ 
     METHODN_NONAME,  /* implements */ 
     METHODN_NONAME,  /* method */ 
+    METHODN_NONAME,  /* function */ 
     METHODN_NONAME,  /* format */ 
     METHODN_NONAME,  /* return */ 
     METHODN_NONAME,  /* mapmap */ 
@@ -207,6 +210,7 @@ static knh_methodn_t knh_token_array_tomethodn[] = {
     METHODN_NONAME,  /* DOTS */ 
     METHODN_NONAME,  /* SEMICOLON */ 
     METHODN_NONAME,  /* COMMA */ 
+    METHODN_NONAME,  /* FUNCMAP */ 
     METHODN_NONAME,  /* LET */ 
     METHODN_NONAME,  /* lshifte */ 
     METHODN_NONAME,  /* rshifte */ 
@@ -305,6 +309,7 @@ static int knh_token_array_getOpPriority[] = {
     0,  /* extends */ 
     0,  /* implements */ 
     0,  /* method */ 
+    0,  /* function */ 
     0,  /* format */ 
     0,  /* return */ 
     0,  /* mapmap */ 
@@ -336,6 +341,7 @@ static int knh_token_array_getOpPriority[] = {
     0,  /* DOTS */ 
     0,  /* SEMICOLON */ 
     0,  /* COMMA */ 
+    99,  /* FUNCMAP */ 
     0,  /* LET */ 
     0,  /* lshifte */ 
     0,  /* rshifte */ 
@@ -434,6 +440,7 @@ static int knh_token_array_getOpSize[] = {
     0,  /* extends */ 
     0,  /* implements */ 
     0,  /* method */ 
+    0,  /* function */ 
     0,  /* format */ 
     0,  /* return */ 
     0,  /* mapmap */ 
@@ -465,6 +472,7 @@ static int knh_token_array_getOpSize[] = {
     0,  /* DOTS */ 
     0,  /* SEMICOLON */ 
     0,  /* COMMA */ 
+    0,  /* FUNCMAP */ 
     0,  /* LET */ 
     0,  /* lshifte */ 
     0,  /* rshifte */ 
@@ -563,6 +571,7 @@ static knh_bool_t knh_token_array_isEndOfStmt[] = {
     1,  /* extends */ 
     1,  /* implements */ 
     1,  /* method */ 
+    1,  /* function */ 
     1,  /* format */ 
     1,  /* return */ 
     1,  /* mapmap */ 
@@ -594,6 +603,7 @@ static knh_bool_t knh_token_array_isEndOfStmt[] = {
     0,  /* DOTS */ 
     1,  /* SEMICOLON */ 
     0,  /* COMMA */ 
+    0,  /* FUNCMAP */ 
     0,  /* LET */ 
     0,  /* lshifte */ 
     0,  /* rshifte */ 
@@ -778,6 +788,7 @@ Token *new_Token__parse(Ctx *ctx, knh_flag_t flag, InputStream *in, knh_bytes_t
         if(ISB(t, "<<")) { tt = TT_LSHIFT; break; }
     break;
     case '=':
+        if(ISB(t, "=>")) { tt = TT_FUNCMAP; break; }
         if(ISB(t, "=")) { tt = TT_LET; break; }
         if(ISB(t, "===")) { tt = TT_IS; break; }
         if(ISB(t, "==")) { tt = TT_EQ; break; }
@@ -846,6 +857,7 @@ Token *new_Token__parse(Ctx *ctx, knh_flag_t flag, InputStream *in, knh_bytes_t
         if(ISB(t, "else")) { tt = TT_ELSE; break; }
     break;
     case 'f':
+        if(ISB(t, "function")) { tt = TT_FUNCTION; break; }
         if(ISB(t, "format")) { tt = TT_FORMAT; break; }
         if(ISB(t, "for")) { tt = TT_FOR; break; }
         if(ISB(t, "foreach")) { tt = TT_FOREACH; break; }
@@ -985,6 +997,7 @@ int knh_bytes_istoken(knh_bytes_t t, int ch)
         if(ISB(t, ">")) { return 1; }
         return 0; 
     case '>':
+        if(ISB(t, "=")) { return 1; }
         if(ISB(t, "--")) { return 1; }
         if(ISB(t, ">")) { return 1; }
         return 0; 
@@ -1027,7 +1040,7 @@ static char* knh_stmt_array_tochar[] = {
     "extends",  /* extends */ 
     "implements",  /* implements */ 
     "method",  /* method */ 
-    "closure",  /* closure */ 
+    "function",  /* function */ 
     "format",  /* format */ 
     "decl",  /* decl */ 
     "return",  /* return */ 
@@ -1062,7 +1075,6 @@ static char* knh_stmt_array_tochar[] = {
     "pcall",  /* pcall */ 
     "mt",  /* mt */ 
     "op",  /* op */ 
-    "invoke",  /* invoke */ 
     "proceed",  /* proceed */ 
     "tri",  /* tri */ 
     "alt",  /* alt */ 
@@ -1099,7 +1111,7 @@ static size_t knh_stmt_array_size[] = {
     0,  /* extends */ 
     5,  /* implements */ 
     5,  /* method */ 
-    3,  /* closure */ 
+    3,  /* function */ 
     7,  /* format */ 
     3,  /* decl */ 
     5,  /* return */ 
@@ -1134,7 +1146,6 @@ static size_t knh_stmt_array_size[] = {
     7,  /* pcall */ 
     3,  /* mt */ 
     7,  /* op */ 
-    1,  /* invoke */ 
     2,  /* proceed */ 
     3,  /* tri */ 
     5,  /* alt */ 
@@ -1172,7 +1183,7 @@ static int knh_stmt_array_isExpr[] = {
     0,  /* extends */ 
     0,  /* implements */ 
     0,  /* method */ 
-    0,  /* closure */ 
+    0,  /* function */ 
     0,  /* format */ 
     0,  /* decl */ 
     0,  /* return */ 
@@ -1207,7 +1218,6 @@ static int knh_stmt_array_isExpr[] = {
     1,  /* pcall */ 
     1,  /* mt */ 
     1,  /* op */ 
-    1,  /* invoke */ 
     1,  /* proceed */ 
     1,  /* tri */ 
     1,  /* alt */ 
