@@ -141,9 +141,9 @@ Mapper* new_Mapper__NoSuchMapping(Ctx *ctx, knh_class_t scid, knh_class_t tcid)
 /* ------------------------------------------------------------------------ */
 
 INLINE
-knh_bool_t knh_Mapper_isNoSuchMapping(Mapper *o)
+knh_bool_t knh_Mapper_isNoSuchMapping(Mapper *mpr)
 {
-	return (DP(o)->fmap == knh_fmapper_null);
+	return ((mpr)->fmap_1 == knh_fmapper_null);
 }
 
 /* ======================================================================== */
@@ -155,7 +155,7 @@ Mapper *knh_tMapper_find_(Ctx *ctx, knh_class_t scid, knh_class_t tcid, int isge
 {
 	KNH_ASSERT_cid(scid);
 	KNH_ASSERT_cid(tcid);
-	DBG2_P("finding.. %s ==> %s", CLASSN(scid), CLASSN(tcid));
+	DBG2_P("finding.. %s ==> %s",CLASSN(scid), CLASSN(tcid));
 	KNH_ASSERT(scid != CLASS_Any); KNH_ASSERT(tcid != CLASS_Nue);
 
 	Mapper *mpr = knh_tmapper_getcache(ctx, scid, tcid);
@@ -180,6 +180,7 @@ Mapper *knh_tMapper_find_(Ctx *ctx, knh_class_t scid, knh_class_t tcid, int isge
 			mpr = DP(cmap)->maplist[i];
 			if(knh_class_instanceof(ctx, DP(mpr)->tcid, tcid)) return knh_tmapper_setcache(ctx, scid, tcid, mpr);
 		}
+		if(sbcid == CLASS_Object) break;
 		for(i = 0; i < DP(cmap)->size; i++) {
 			ClassMap *cmap2 = ctx->tClass[DP(DP(cmap)->maplist[i])->tcid].cmap;
 			int j;
@@ -197,8 +198,7 @@ Mapper *knh_tMapper_find_(Ctx *ctx, knh_class_t scid, knh_class_t tcid, int isge
 				}
 			}
 		}
-		if(sbcid == CLASS_Object) break;
-		if(knh_tClass_isPMZ(sbcid) && ctx->tClass[sbcid].bcid != sbcid) {
+		if(knh_Class_isGenerics(sbcid) && ctx->tClass[sbcid].bcid != sbcid) {
 			sbcid = ctx->tClass[sbcid].bcid;
 		}
 		else {
